MODULE VariableBlinker;
(* =========================================================================  
   Example Oberon ARM Cortex-M3 Program  
 
   Description:
     Led connected to P0.22 blinking approx. once per second

   Target:
     NXP LPC1769
     
   Tested on: 
     LPCxpresso LPC1769
   
   References: 
     NXP UM10360 LPC17xx User manual
     Oberon for Cortex-M3 Microcontrollers
   
   (c) 2012-2014 CFB Software   
   http://www.astrobe.com  
   
   ========================================================================= *)

IMPORT Main, MCU, Serial, SYSTEM, Timer;

PROCEDURE Run();
CONST
  (* led connected to pin P0.22 *)
  ledBit = {22};
VAR
  direction: SET;
  ch: CHAR;
  n, delay: INTEGER;
BEGIN
  (* Set led pin as output by setting the direction bit *)
  SYSTEM.GET(MCU.FIO0DIR, direction);
  SYSTEM.PUT(MCU.FIO0DIR, direction + ledBit);
  
  ch := 0X;
  delay := 500;
  WHILE TRUE DO
    IF Serial.RxReady() & (ch = 0X) THEN 
      Serial.GetCh(ch);
      n := ORD(ch) - ORD("0");
      IF n IN {1..9} THEN delay := n * 100 END
    END;
    IF Serial.TxReady() & (ch # 0X)  THEN 
      Serial.PutCh(ch);
      ch := 0X
    END;
    SYSTEM.PUT(MCU.FIO0CLR, ledBit);
    Timer.MSecDelay(delay);
    SYSTEM.PUT(MCU.FIO0SET, ledBit);
    Timer.MSecDelay(delay)
  END
END Run;

BEGIN
  Run()
END VariableBlinker.
